hide abstract method
Hides the progress dialog.
This method is used to hide the progress dialog when the ongoing process is complete or when it's no longer needed.
Returns a Future of type T, indicating that the dialog has been closed.
Implementation
Future<T> hide();