show abstract method
Shows the progress dialog with an optional message.
This method is used to display the progress dialog, optionally providing a message to explain what process is ongoing.
msg: An optional message to display in the progress dialog.
Returns a Future of type T, which completes when the dialog is hidden.
Implementation
Future<T> show({String? msg});