jstate library
Classes
-
JController<
T extends JState> - Base controller for managing state and side effects in a reactive architecture.
-
JIntent<
T extends JState> - Represents an action or event that can modify application state.
- A service class that encapsulates navigation functionality in the application.
- JState
- An immutable base class representing the state in an application.