The list of properties used to determine equality.
This list should include all properties that are considered significant for determining if two instances of JState are the same.
JState
@override List<Object?> get props;